<?php


namespace Intergo\InventoryClient;


use Intergo\BaseClient\Responses\BaseResponseInterface;

class InventoryService
{
    /** @var string */
    public string $baseUrl;

    /** @var InventoryClient */
    private InventoryClient $client;

    /** @var string */
    private string $secret;

    /** @var string */
    protected string $site;

    /** @var string */
    protected string $traceId;

    /**
     * InventoryService constructor.
     */
    public function __construct($site, $baseUrl, $secret, $traceId)
    {
        $this->baseUrl = $baseUrl;
        $this->client = new InventoryClient();
        $this->secret = $secret;
        $this->site = $site;
        $this->traceId = $traceId;
    }

    /**
     * @param string $endpoint
     * @param array $params
     * @return BaseResponseInterface
     */
    private function execute(string $endpoint, array $params): BaseResponseInterface
    {
        return $this->client->execute($endpoint, $this->baseUrl, $params, $this->traceId);
    }

    public function allowedCountries(): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }

    /**
     * @param null $type
     * @param null $number
     * @param null $service
     * @param null $country
     * @return BaseResponseInterface
     */
    public function inventories($type = null, $number = null, $service = null, $country = null): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }

    /**
     * @return BaseResponseInterface
     */
    public function subscriptions(): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }

    /**
     * @param int $id
     * @return BaseResponseInterface
     */
    public function subscriptionRenewals(int $id): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }

    /**
     * @param int $id
     * @return BaseResponseInterface
     */
    public function renew(int $id): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }

    /**
     * @param int $id
     * @return BaseResponseInterface
     */
    public function cancel(int $id): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }

    public function userInventoryByNumber($number): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }

    public function inventoryPlans(int $inventoryID): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }

    public function requestInventory(int $user_id, int $plan_id, int $inventory_id, string $keyword = null): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }

    public function userInventories($id): BaseResponseInterface
    {
        return $this->execute(__FUNCTION__, get_defined_vars());
    }
}
